@@ -1,7 +1,7 @@
 package Module::Abstract::Cwalitee;
 
-our $DATE = '2019-07-06'; # DATE
-our $VERSION = '0.002'; # VERSION
+our $DATE = '2019-07-07'; # DATE
+our $VERSION = '0.003'; # VERSION
 
 use 5.010001;
 use strict 'subs', 'vars';
@@ -21,7 +21,7 @@ our %SPEC;
 $SPEC{list_module_abstract_cwalitee_indicators} = {
     v => 1.1,
     args => {
-        %Cwalitee::Common::args_list,
+        Cwalitee::Common::args_list('Module::Abstract::'),
     },
 };
 sub list_module_abstract_cwalitee_indicators {
@@ -36,7 +36,7 @@ sub list_module_abstract_cwalitee_indicators {
 $SPEC{calc_module_abstract_cwalitee} = {
     v => 1.1,
     args => {
-        %Cwalitee::Common::args_calc,
+        Cwalitee::Common::args_calc('Module::Abstract::'),
         abstract => {
             schema => 'str*',
             req => 1,
@@ -74,7 +74,7 @@ Module::Abstract::Cwalitee - Calculate the cwalitee of your module Abstract
 
 =head1 VERSION
 
-This document describes version 0.002 of Module::Abstract::Cwalitee (from Perl distribution Module-Abstract-Cwalitee), released on 2019-07-06.
+This document describes version 0.003 of Module::Abstract::Cwalitee (from Perl distribution Module-Abstract-Cwalitee), released on 2019-07-07.
 
 =head1 SYNOPSIS
 
@@ -196,11 +196,11 @@ Include by module.
 
 Include by status.
 
-=item * B<max_severity> => I<uint> (default: 5)
+=item * B<max_severity> => I<int> (default: 5)
 
 Maximum severity.
 
-=item * B<min_severity> => I<uint> (default: 1)
+=item * B<min_severity> => I<int> (default: 1)
 
 Minimum severity.
 
